@@ -989,7 +989,16 @@ class BaseCommand:
         # repository path, as well as all remote paths for the repository. If
         # one is found, we want to merge that into the config dictionary and
         # restart the entire initialization process.
-        if 'TREES' in self.config:
+        if trees := self.config.get('TREES'):
+            # If we haven't attempted to initialize a client yet (either
+            # through _init_server_url or with needs_scm_client), try one last
+            # time. People who are using TREES often are using repository paths
+            # as the keys, which means we need a repository.
+            if repository_info is None and tool is None:
+                repository_info, tool = self.initialize_scm_tool(
+                    client_name=getattr(self.options, 'repository_type', None),
+                    tool_required=False)
+
             paths: list[str] = []
 
             if repository_info is not None:
@@ -1003,8 +1012,6 @@ class BaseCommand:
             else:
                 paths.append(os.getcwd())
 
-            trees = self.config['TREES']
-
             if not isinstance(trees, dict):
                 raise CommandError(
                     'TREES is defined in the Review Board configuration, but '
@@ -1168,9 +1175,15 @@ class BaseCommand:
     def initialize_scm_tool(
         self,
         client_name: Optional[str] = None,
-    ) -> tuple[RepositoryInfo, BaseSCMClient]:
+        *,
+        tool_required: bool = True,
+    ) -> tuple[Optional[RepositoryInfo], Optional[BaseSCMClient]]:
         """Initialize the SCM tool for the current working directory.
 
+        Version Changed:
+            5.0.3:
+            Added the ``tool_required`` argument.
+
         Version Changed:
             5.0:
             Removed deprecated ``require_repository_info`` argument.
@@ -1181,6 +1194,12 @@ class BaseCommand:
                 This can be used to disambiguate if there are nested
                 repositories, or to speed up detection.
 
+            tool_required (bool, optional):
+                Whether a tool is required to be found or not.
+
+                Version Added:
+                    5.0.3
+
         Returns:
             tuple:
             A 2-tuple:
@@ -1195,7 +1214,11 @@ class BaseCommand:
         repository_info, tool = scan_usable_client(
             self.config,
             self.options,
-            client_name=client_name)
+            client_name=client_name,
+            tool_required=tool_required)
+
+        if tool is None and not tool_required:
+            return repository_info, None
 
         try:
             tool.check_options()
